@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2018-2019 by the Free Software Foundation, Inc.
+# Copyright (C) 2018-2021 by the Free Software Foundation, Inc.
 #
 # This file is part of Django-Mailman.
 #
@@ -19,11 +19,11 @@
 #
 
 
+from unittest.mock import Mock
+
 from django.contrib.auth.models import User
 from django.urls import reverse
 
-from mock import Mock
-
 from django_mailman3.models import Profile
 from django_mailman3.tests.utils import TestCase
 
@@ -33,6 +33,7 @@ class AccountDeletionTests(TestCase):
     def setUp(self):
         self.mm_user = Mock()
         self.mm_user.user_id = "dummy"
+        self.mm_user.addresses = [Mock()]
         self.mailman_client.get_user.side_effect = lambda e: self.mm_user
         self.user = User.objects.create_user(
             'testuser', 'test@example.com', 'testPass',
